@@ -10,6 +10,9 @@ import logging
 
 log = logging.getLogger('oauth_tokens')
 
+class OAuthError(Exception):
+    pass
+
 class BaseAccessToken(object):
 
     user = None
